@@ -11,13 +11,16 @@ import Network.HTTP.Date.Types
 
 ----------------------------------------------------------------
 
-{-|
-  Parsing HTTP Date. Currently only RFC1123 style is supported.
--}
+-- |
+-- Parsing HTTP Date. Currently only RFC1123 style is supported.
+--
+-- >>> parseHTTPDate "Tue, 15 Nov 1994 08:12:31 GMT"
+-- Just (HTTPDate {hdYear = 1994, hdMonth = 11, hdDay = 15, hdHour = 8, hdMinute = 12, hdSecond = 31, hdWkday = 2})
+
 parseHTTPDate :: ByteString -> Maybe HTTPDate
-parseHTTPDate bs = case feed (parse rfc1123Date bs) "" of
-    Done _ ut -> Just ut
-    _         -> Nothing
+parseHTTPDate bs = case parseOnly rfc1123Date bs of
+    Right ut -> Just ut
+    _        -> Nothing
 
 rfc1123Date :: Parser HTTPDate
 rfc1123Date = do
